


04/16/93 E. Correia
WK#:581       MV#:3c
Breitkopf & H\3artel, Vol. 13
Clarinet Quintet
Trio II
Violoncello
1 0 
Group memberships: sound, score
sound: part 5 of 5
score: part 5 of 5
$  K:3   Q:2   T:3/4   C:22
rest   2        q
measure 1
A3     2        q     d        p
rest   2        q
rest   2        q
measure 2
D3     2        q     d
rest   2        q
rest   2        q
measure 3
E3     2        q     d
rest   2        q
rest   2        q
measure 4
F#3    2        q     d
rest   2        q
rest   2        q
measure 5
C#3    2        q     u
rest   2        q
rest   2        q
measure 6
D3     2        q     d
rest   2        q
rest   2        q
measure 7
rest   6
measure 8
rest   6
measure 9
rest   6
measure 10
rest   6
measure 11
E2     2        q     u        (.
E2     2        q     u         .
E2     2        q     u        ).
measure 12
A2     2        q     u
rest   2        q
mheavy4         :||:
/END